@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2011 Jacek Sieka, arnetheduck on gmail point com
+ * Copyright (C) 2001-2012 Jacek Sieka, arnetheduck on gmail point com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,12 @@
 #include "Streams.h"
 #include "HashManagerListener.h"
 
+#ifdef USE_XATTR
+#include "attr/attributes.h"
+#else
+#define ATTR_MAX_VALUELEN 128
+#endif
+
 namespace dcpp {
 
 STANDARD_EXCEPTION(HashException);
@@ -225,6 +231,32 @@ private:
     Hasher hasher;
     HashStore store;
 
+    class StreamStore
+    {
+    public:
+        struct TTHStreamHeader
+        {
+            uint32_t magic;
+            uint32_t checksum;
+            uint64_t fileSize;
+            uint64_t timeStamp;
+            uint64_t blockSize;
+            TTHValue root;
+        };
+
+        bool loadTree(const string& p_filePath, TigerTree &tree, int64_t p_aFileSize = -1);
+        bool saveTree(const string& p_filePath, const TigerTree& p_Tree);
+        void deleteStream(const string& p_filePath);
+
+    private:
+        static const uint32_t g_MAGIC = 0x2b2b6c67;
+        static const string g_streamName;
+
+        void setCheckSum(TTHStreamHeader& p_header);
+        bool validateCheckSum(const TTHStreamHeader& p_header);
+    };
+    StreamStore m_streamstore;
+
     mutable CriticalSection cs;
 
     /** Single node tree where node = root, no storage in HashData.dat */
