@@ -46,7 +46,7 @@ class SearchQueue
 public:
 
     SearchQueue(uint32_t aInterval = 0)
-        : lastSearchTime(0), interval(aInterval)
+        : interval(aInterval), lastSearchTime(0)
     {
     }
 
