@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2011 Jacek Sieka, arnetheduck on gmail point com
+ * Copyright (C) 2001-2012 Jacek Sieka, arnetheduck on gmail point com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ public:
     int64_t aSize, const string& aFile, const string& aHubName,
     const string& aHubURL, const string& ip, TTHValue aTTH, const string& aToken);
 
-    string getFileName() const;
+    string getBaseName() const;
     string toSR(const Client& client) const;
     AdcCommand toRES(char type) const;
 
