@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2011 Jacek Sieka, arnetheduck on gmail point com
+ * Copyright (C) 2001-2012 Jacek Sieka, arnetheduck on gmail point com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,6 @@ public:
     virtual ~Singleton() { }
 
     static T* getInstance() {
-        dcassert(instance);
         return instance;
     }
 
@@ -49,8 +48,8 @@ public:
     }
 
     static void deleteInstance() {
-        if(instance)
-            delete instance;
+        delete instance;
+
         instance = NULL;
     }
     virtual void release(){
