@@ -205,7 +205,7 @@ namespace dht
 	 */
 	void KBucket::getClosestNodes(const CID& cid, Node::Map& closest, unsigned int max, uint8_t maxType) const
 	{
-		for(NodeList::const_iterator it = nodes.begin(); it != nodes.end(); it++)
+		for(NodeList::const_iterator it = nodes.begin(); it != nodes.end(); ++it)
 		{
 			const Node::Ptr& node = *it;
 			if(node->getType() <= maxType && node->isIpVerified() && !node->getUser()->isSet(User::PASSIVE))
@@ -294,7 +294,7 @@ namespace dht
 
 #ifdef _DEBUG
 		int verified = 0; int types[5] = { 0 };
-		for(NodeList::const_iterator j = nodes.begin(); j != nodes.end(); j++)
+		for(NodeList::const_iterator j = nodes.begin(); j != nodes.end(); ++j)
 		{
 			Node::Ptr n = *j;
 			if(n->isIpVerified()) verified++;
@@ -356,7 +356,7 @@ namespace dht
 		Node::Map closestToMe;
 		getClosestNodes(CID::generate(), closestToMe, 50, 3);
 
-		for(Node::Map::const_iterator j = closestToMe.begin(); j != closestToMe.end(); j++)
+		for(Node::Map::const_iterator j = closestToMe.begin(); j != closestToMe.end(); ++j)
 		{
 			const Node::Ptr& node = j->second;
 
@@ -374,7 +374,7 @@ namespace dht
 			StringMap params;
 			node->getIdentity().getParams(params, Util::emptyString, false, true);
 
-			for(StringMap::const_iterator i = params.begin(); i != params.end(); i++)
+			for(StringMap::const_iterator i = params.begin(); i != params.end(); ++i)
 				xml.addChildAttrib(i->first, i->second);
 		}
 
