@@ -13,7 +13,7 @@
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 // stdafx.h : include file for standard system include files,
@@ -24,13 +24,11 @@
 #define _STDAFX_H
 
 #include "dcpp/stdinc.h"
-#include "dcpp/DCPlusPlus.h"
 
 namespace dht
 {
 	using namespace dcpp;
 	using namespace std;
-	using namespace std::tr1;
 }
 
 // TODO: reference additional headers your program requires here
