@@ -26,13 +26,13 @@ use JSON::RPC::Client;
 use Term::ShellUI;
 use Data::Dump qw[dump];
 use Getopt::Long;
-use Env qw[$XDG_CONFIG_HOME];
+use Env qw[$XDG_CONFIG_HOME $HOME];
 
 # use non-standart paths
 BEGIN {
     unshift @INC, 
 	 "$XDG_CONFIG_HOME/eiskaltdc++",
-	 "~/.config/eiskaltdc++/",
+	 "$HOME/.config/eiskaltdc++/",
 	 "/usr/local/share/eiskaltdcpp/cli",
 	 "/usr/share/eiskaltdcpp/cli"
 }
@@ -45,7 +45,7 @@ our %config;
 $config{version}=0.1;
 require "cli-jsonrpc-config.pl";
 my $version,my $help;
-GetOptions ('v|version' => \$version, 'h|help' => \$help);
+GetOptions ('V|version' => \$version, 'h|help' => \$help);
 if ($version)
 {
 	print("Command line JSON-RPC interface version: $config{version}\n"); exit(1);
@@ -60,7 +60,7 @@ EiskaltDC++ is a cross-platform program that uses the Direct Connect and ADC pro
 
 Keys:
 \t-h, --help\t Show this message
-\t-v, --version\t Show version string\n");
+\t-V, --version\t Show version string\n");
 	exit(1);
 }
 print("Configuration:\n");
@@ -77,6 +77,7 @@ my $res;
 # creating and configuring client
 my $client = new JSON::RPC::Client;
 $client->version("2.0");
+$client->ua->timeout(10);
 #$client->ua->credentials('http://127.0.0.1:3121', 'jsonrpc', 'user' => 'password');
 
 # creating shell
@@ -228,6 +229,22 @@ sub get_commands
 			maxargs => 2,
 			proc => \&qsetprio
 		},
+		"queue.list" =>
+		{
+			desc => "Show queue, including all targets. Parameters: none",
+			proc => \&qlist
+		},
+		"queue.listtargets" =>
+		{
+			desc => "Show  all targets. Parameters: none",
+			proc => \&qlisttargets
+		},
+		"search.clear" =>
+		{
+			desc => "Clear search results. Parameters: huburl",
+			maxargs => 1,
+			proc => \&searchclear
+		},
 		# last
 		"prompt" =>
 		{
@@ -764,6 +781,76 @@ sub qsetprio($$)
 	delete($obj->{'params'});
 }
 
+sub qlist()
+{
+	$obj->{'id'} = int(rand(2**16));
+	$obj->{'method'} = 'queue.list';
+	print("===Request===\n".dump($obj)."\n");
+	$res = $client->call($config{eiskaltURL}, $obj);
+	if ($res)
+	{
+		if ($res->is_error) 
+		{
+			print("===Error===\n".dump($res->error_message)."\n");
+		}
+		else
+		{
+			print("===Reply===\n".dump($res->result)."\n");
+		}
+	}
+	else
+	{
+		print $client->status_line;
+	}
+}
+
+sub qlisttargets()
+{
+	$obj->{'id'} = int(rand(2**16));
+	$obj->{'method'} = 'queue.listtargets';
+	print("===Request===\n".dump($obj)."\n");
+	$res = $client->call($config{eiskaltURL}, $obj);
+	if ($res)
+	{
+		if ($res->is_error) 
+		{
+			print("===Error===\n".dump($res->error_message)."\n");
+		}
+		else
+		{
+			print("===Reply===\n".dump($res->result)."\n");
+		}
+	}
+	else
+	{
+		print $client->status_line;
+	}
+}
+
+sub searchclear($)
+{
+	$obj->{'id'} = int(rand(2**16));
+	$obj->{'method'} = 'search.clear';
+	if (defined($_[0])) {$obj->{'params'}->{'huburl'}=$_[0]};
+	print("===Request===\n".dump($obj)."\n");
+	$res = $client->call($config{eiskaltURL}, $obj);
+	if ($res)
+	{
+		if ($res->is_error) 
+		{
+			print("===Error===\n".dump($res->error_message)."\n");
+		}
+		else
+		{
+			print("===Reply===\n".dump($res->result)."\n");
+		}
+	}
+	else
+	{
+		print $client->status_line;
+	}
+	delete($obj->{'params'});
+}
 __END__
 
 =pod
