@@ -32,7 +32,12 @@ BookEntry::BookEntry(const EntryType type, const string &text, const string &ui,
     bold(FALSE),
     urgent(FALSE)
 {
+#if GTK_CHECK_VERSION(3, 2, 0)
+    labelBox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,5);
+#else
     labelBox = gtk_hbox_new(FALSE, 5);
+#endif
+
 
     eventBox = gtk_event_box_new();
     gtk_event_box_set_above_child(GTK_EVENT_BOX(eventBox), TRUE);
@@ -55,25 +60,20 @@ BookEntry::BookEntry(const EntryType type, const string &text, const string &ui,
     gtk_button_set_relief(GTK_BUTTON(closeButton), GTK_RELIEF_NONE);
     gtk_button_set_focus_on_click(GTK_BUTTON(closeButton), FALSE);
 
+#if !GTK_CHECK_VERSION(3, 0, 0)
     // Shrink the padding around the close button
     GtkRcStyle *rcstyle = gtk_rc_style_new();
     rcstyle->xthickness = rcstyle->ythickness = 0;
     gtk_widget_modify_style(closeButton, rcstyle);
     g_object_unref(rcstyle);
+#endif
 
     // Add the stock icon to the close button
     GtkWidget *image = gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
     gtk_container_add(GTK_CONTAINER(closeButton), image);
     gtk_box_pack_start(GTK_BOX(labelBox), closeButton, FALSE, FALSE, 0);
 
-#if GTK_CHECK_VERSION(2, 12, 0)
     gtk_widget_set_tooltip_text(closeButton, _("Close tab"));
-#else
-    tips = gtk_tooltips_new();
-    g_object_ref_sink(tips);
-    gtk_tooltips_enable(tips);
-    gtk_tooltips_set_tip(tips, closeButton, _("Close tab"), NULL);
-#endif
     gtk_widget_show_all(labelBox);
 
     tabMenuItem = gtk_radio_menu_item_new_with_label(group, text.c_str());
@@ -133,11 +133,7 @@ void BookEntry::setLabel_gui(string text)
         gtk_label_set_text(GTK_LABEL(child), text.c_str());
 
     // Update the notebook tab label
-#if GTK_CHECK_VERSION(2, 12, 0)
     gtk_widget_set_tooltip_text(eventBox, text.c_str());
-#else
-    gtk_tooltips_set_tip(tips, eventBox, text.c_str(), text.c_str());
-#endif
     glong len = g_utf8_strlen(text.c_str(), -1);
 
     // Truncate the label text
@@ -218,6 +214,9 @@ void BookEntry::updateLabel_gui()
     char *markup = g_markup_printf_escaped(format, truncatedLabelText.c_str());
     gtk_label_set_markup(label, markup);
     g_free(markup);
+#if GTK_CHECK_VERSION(3, 0, 0)
+    gtk_widget_queue_draw (GTK_WIDGET (label));
+#endif
 }
 
 const string& BookEntry::getLabelText()
