@@ -45,11 +45,7 @@ FavoriteHubs::FavoriteHubs():
 	// Fill the charset drop-down list in edit fav hub dialog.
 	vector<string> &charsets = WulforUtil::getCharsets();
 	for (vector<string>::const_iterator it = charsets.begin(); it != charsets.end(); ++it)
-#if (((GTK_MAJOR_VERSION == 2) && (GTK_MINOR_VERSION >= 24)) || GTK_MAJOR_VERSION > 2)
         gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(getWidget("comboboxCharset")), it->c_str());
-#else
-        gtk_combo_box_append_text(GTK_COMBO_BOX(getWidget("comboboxCharset")), it->c_str());
-#endif
 
 	// Initialize favorite hub list treeview
 	favoriteView.setView(GTK_TREE_VIEW(getWidget("favoriteView")), TRUE, "favoritehubs");
@@ -77,7 +73,11 @@ FavoriteHubs::FavoriteHubs():
 	// Treat "Name" as the default col instead of "Auto Connect"
 	gtk_tree_view_set_search_column(favoriteView.get(), favoriteView.col(_("Name")));
 	GtkTreeViewColumn *column = gtk_tree_view_get_column(favoriteView.get(), favoriteView.col(_("Name")));
+#if GTK_CHECK_VERSION(3, 0, 0)
+	gtk_widget_grab_focus(gtk_tree_view_column_get_button(column));
+#else
 	gtk_widget_grab_focus(column->button);
+#endif
 
 	// Connect the signals to their callback functions.
 	g_signal_connect(getWidget("buttonNew"), "clicked", G_CALLBACK(onAddEntry_gui), (gpointer)this);
@@ -365,11 +365,7 @@ bool FavoriteHubs::showFavoriteHubDialog_gui(StringMap &params, FavoriteHubs *fh
 
 		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(fh->getWidget("checkbuttonEncoding"))))
 		{
-#if (((GTK_MAJOR_VERSION == 2) && (GTK_MINOR_VERSION >= 24)) || GTK_MAJOR_VERSION > 2)
             gchar *encoding = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(fh->getWidget("comboboxCharset")));
-#else
-            gchar *encoding = gtk_combo_box_get_active_text(GTK_COMBO_BOX(fh->getWidget("comboboxCharset")));
-#endif
 			params["Encoding"] = string(encoding);
 			g_free(encoding);
 		}
