@@ -35,6 +35,10 @@ using namespace dcpp;
 SearchSpy::SearchSpy():
 	BookEntry(Entry::SEARCH_SPY, _("Search Spy"), "searchspy.ui")
 {
+#if !GTK_CHECK_VERSION(3,0,0)
+	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR(getWidget("statusbar")),FALSE);
+#endif
+
 	FrameSize = (SearchType)WGETI("search-spy-frame");
 	Waiting = (guint)WGETI("search-spy-waiting");
 	Top = (guint)WGETI("search-spy-top");
