@@ -532,7 +532,6 @@ void Transfers::updateParent_gui(GtkTreeIter* iter)
     GtkTreeIter child;
     string users;
     set<string> hubs;
-    bool valid;
     int64_t speed = 0;
     int64_t position = 0;
     int64_t totalSize = 0;
@@ -548,7 +547,7 @@ void Transfers::updateParent_gui(GtkTreeIter* iter)
     if (gtk_tree_model_iter_has_child(GTK_TREE_MODEL(transferStore), iter))
     {
         child = *iter;
-        valid = WulforUtil::getNextIter_gui(GTK_TREE_MODEL(transferStore), &child, TRUE, FALSE);
+        bool valid = WulforUtil::getNextIter_gui(GTK_TREE_MODEL(transferStore), &child, TRUE, FALSE);
         while (valid)
         {
             if (transferView.getValue<int>(&child, "Failed") == 0 &&
@@ -606,7 +605,6 @@ void Transfers::updateTransfer_gui(StringMap params, bool download, Sound::TypeS
     GtkTreeIter iter, parent;
     if (!findTransfer_gui(params["CID"], download, &iter))
     {
-        int invalid_transfer_CID_not_found = 0;
         dcdebug(_("Transfers::updateTransfer, CID not found %s\n"), params["CID"].c_str());
         // Transfer not found. Usually this *shouldn't* happen, but I guess it's possible since tick updates are sent by TimerManager
         // and removing is handled by dl manager.
@@ -670,8 +668,7 @@ void Transfers::initTransfer_gui(StringMap params)
 
     if (!findTransfer_gui(params["CID"], TRUE, &iter))
     {
-        int connection_not_found = 0;
-        dcassert(connection_not_found); // not really fatal only annoying as the dl can't be seen, can be ignored in release build
+        dcassert(0); // not really fatal only annoying as the dl can't be seen, can be ignored in release build
         return;
     }
 
