@@ -89,7 +89,7 @@ string TreeView::getString(GtkTreeIter *i, const string &column, GtkTreeModel *m
 void TreeView::insertColumn(const string &title, const GType &gtype, const columnType type, const int width, const string &linkedCol)
 {
     // All insertColumn's have to be called before any insertHiddenColumn's.
-    dcassert(hiddenColumns.size() == 0);
+    dcassert(hiddenColumns.empty());
 
     // Title must be unique.
     dcassert(!title.empty() && columns.find(title) == columns.end());
@@ -103,7 +103,7 @@ void TreeView::insertColumn(const string &title, const GType &gtype, const colum
     const string &linkedCol, const string &linkedTextColor)
 {
     // All insertColumn's have to be called before any insertHiddenColumn's.
-    dcassert(hiddenColumns.size() == 0);
+    dcassert(hiddenColumns.empty());
 
     // Title must be unique.
     dcassert(!title.empty() && columns.find(title) == columns.end());
@@ -136,7 +136,7 @@ void TreeView::finalize()
     if (!name.empty())
         restoreSettings();
 
-    for (SortedColIter iter = sortedColumns.begin(); iter != sortedColumns.end(); iter++)
+    for (SortedColIter iter = sortedColumns.begin(); iter != sortedColumns.end(); ++iter)
     {
         Column& col = columns[iter->second];
         addColumn_gui(col);
@@ -193,9 +193,9 @@ GType* TreeView::getGTypes()
         return gtypes;
     gtypes = new GType[count];
 
-    for (SortedColIter iter = sortedColumns.begin(); iter != sortedColumns.end(); iter++)
+    for (SortedColIter iter = sortedColumns.begin(); iter != sortedColumns.end(); ++iter)
         gtypes[i++] = columns[iter->second].gtype;
-    for (SortedColIter iter = sortedHiddenColumns.begin(); iter != sortedHiddenColumns.end(); iter++)
+    for (SortedColIter iter = sortedHiddenColumns.begin(); iter != sortedHiddenColumns.end(); ++iter)
         gtypes[i++] = hiddenColumns[iter->second].gtype;
 
     return gtypes;
@@ -362,7 +362,11 @@ void TreeView::addColumn_gui(Column& column)
      * Breaks GTK+ API, but is the only way to attach a signal to a gtktreeview column header. See GTK bug #141937.
      * @todo: Replace when GTK adds a way to add a signal to the entire header (remove visibleColumns var, too).
      */
+#if GTK_CHECK_VERSION(3, 0, 0)
+    g_signal_connect(gtk_tree_view_column_get_button(col) , "button-release-event", G_CALLBACK(popupMenu_gui), (gpointer)this);
+#else
     g_signal_connect(col->button, "button-release-event", G_CALLBACK(popupMenu_gui), (gpointer)this);
+#endif
 }
 
 void TreeView::setSortColumn_gui(const string &column, const string &sortColumn)
@@ -409,7 +413,7 @@ void TreeView::toggleColumnVisibility(GtkMenuItem *item, gpointer data)
     string title = string(gtk_label_get_text(GTK_LABEL(gtk_bin_get_child(GTK_BIN(item)))));
 
     // Function col(title) doesn't work here, so we have to find column manually.
-    for (iter = tv->sortedColumns.begin(); iter != tv->sortedColumns.end(); iter++)
+    for (iter = tv->sortedColumns.begin(); iter != tv->sortedColumns.end(); ++iter)
     {
         column = gtk_tree_view_get_column(tv->view, iter->first);
         if (string(gtk_tree_view_column_get_title(column)) == title)
@@ -477,7 +481,7 @@ void TreeView::saveSettings()
     GtkTreeViewColumn *col;
     gint width;
 
-    dcassert(columns.size() > 0);
+    dcassert(!columns.empty());
 
     for (size_t i = 0; i < columns.size(); i++)
     {
