@@ -10,6 +10,7 @@
 #include "ScriptEngine.h"
 
 #include "ArenaWidget.h"
+#include "ArenaWidgetFactory.h"
 #include "MainWindow.h"
 #include "Antispam.h"
 #include "DownloadQueue.h"
@@ -21,6 +22,8 @@
 #include "SearchFrame.h"
 #include "ShellCommandRunner.h"
 #include "WulforSettings.h"
+#include "DebugHelper.h"
+#include "GlobalTimer.h"
 
 #include "scriptengine/ClientManagerScript.h"
 #include "scriptengine/HashManagerScript.h"
@@ -31,7 +34,7 @@
 #include <QDir>
 #include <QFile>
 #include <QTextStream>
-#include <QtDebug>
+#include <QScriptValueIterator>
 
 #ifndef CLIENT_SCRIPTS_DIR
 #define CLIENT_SCRIPTS_DIR
@@ -46,16 +49,30 @@ static QScriptValue parseChatLinks(QScriptContext*, QScriptEngine*);
 static QScriptValue parseMagnetAlias(QScriptContext*, QScriptEngine*);
 static QScriptValue eval(QScriptContext*, QScriptEngine*);
 static QScriptValue includeFile(QScriptContext*, QScriptEngine*);
+static QScriptValue printErr(QScriptContext*, QScriptEngine*);
+QScriptValue ScriptVarMapToScriptValue(QScriptEngine* eng, const VarMap& map);
+void ScriptVarMapFromScriptValue( const QScriptValue& value, VarMap& map);
 
 ScriptEngine::ScriptEngine() :
         QObject(NULL)
 {
-    connect (WulforSettings::getInstance(), SIGNAL(strValueChanged(QString,QString)), this, SLOT(slotWSKeyChanged(QString,QString)));
+    DEBUG_BLOCK
+    
+    setObjectName("ScriptEngine");
+    
+    qRegisterMetaType<ArenaWidget::Flags>("Flags");
+    qRegisterMetaType<ArenaWidget::Flags>("ArenaWidget::Flags");
+        
+    connect(WulforSettings::getInstance(), SIGNAL(strValueChanged(QString,QString)), this, SLOT(slotWSKeyChanged(QString,QString)));
+    connect(&watcher, SIGNAL(fileChanged(QString)), this, SLOT(slotScriptChanged(QString)));
+    connect(GlobalTimer::getInstance(), SIGNAL(second()), this ,SLOT(slotProcessChangedFiles()));
 
     loadScripts();
 }
 
 ScriptEngine::~ScriptEngine(){
+    DEBUG_BLOCK
+    
     stopScripts();
 
     ClientManagerScript::deleteInstance();
@@ -63,6 +80,8 @@ ScriptEngine::~ScriptEngine(){
 }
 
 void ScriptEngine::loadScripts(){
+    DEBUG_BLOCK
+    
     QStringList enabled = QString(QByteArray::fromBase64(WSGET(WS_APP_ENABLED_SCRIPTS).toAscii())).split("\n");
 
     foreach (QString s, enabled)
@@ -70,10 +89,14 @@ void ScriptEngine::loadScripts(){
 }
 
 void ScriptEngine::loadScript(const QString &path){
+    DEBUG_BLOCK
+    
     QFile f(path);
 
-    if (!f.exists() || scripts.contains(path))
+    if (!f.exists())
         return;
+    
+    stopScript(path);
 
     if (path.endsWith(".js", Qt::CaseInsensitive))
         loadJSScript(path);
@@ -84,6 +107,8 @@ void ScriptEngine::loadScript(const QString &path){
 }
 
 void ScriptEngine::loadJSScript(const QString &file){
+    DEBUG_BLOCK
+    
     QFile f(file);
 
     if (!f.open(QIODevice::ReadOnly))
@@ -101,8 +126,10 @@ void ScriptEngine::loadJSScript(const QString &file){
     obj->engine.globalObject().setProperty("SCRIPT_PATH", scriptPath);
 
     scripts.insert(file, obj);
+    
+    watcher.addPath(file);
 
-    obj->engine.evaluate(data);
+    obj->engine.evaluate(data, file);
 
     if (obj->engine.hasUncaughtException()){
         foreach (QString s, obj->engine.uncaughtExceptionBacktrace())
@@ -112,15 +139,15 @@ void ScriptEngine::loadJSScript(const QString &file){
 
 #ifdef USE_QML
 void ScriptEngine::loadQMLScript(const QString &file){
-    DeclarativeWidget *wgt = new DeclarativeWidget(file);
-
-    MainWindow::getInstance()->addArenaWidget(wgt);
-    MainWindow::getInstance()->addArenaWidgetOnToolbar(wgt);
-    MainWindow::getInstance()->mapWidgetOnArena(wgt);
+    DEBUG_BLOCK
+    
+    DeclarativeWidget *wgt = ArenaWidgetFactory().create<DeclarativeWidget, QString>(file);
 }
 #endif
 
 void ScriptEngine::stopScripts(){
+    DEBUG_BLOCK
+    
     QMap<QString, ScriptObject*> s = scripts;
     QMap<QString, ScriptObject*>::iterator it = s.begin();
 
@@ -131,9 +158,13 @@ void ScriptEngine::stopScripts(){
 }
 
 void ScriptEngine::stopScript(const QString &path){
+    DEBUG_BLOCK
+    
     if (!scripts.contains(path))
         return;
 
+    watcher.removePath(path);
+    
     ScriptObject *obj = scripts.value(path);
 
     obj->engine.globalObject().property("deinit").call();
@@ -149,9 +180,19 @@ void ScriptEngine::stopScript(const QString &path){
     delete obj;
 }
 
-void ScriptEngine::prepareThis(QScriptEngine &engine){
-    setObjectName("ScriptEngine");
+void ScriptEngine::slotProcessChangedFiles() {
+    DEBUG_BLOCK
+    
+    foreach(const QString &file , changedFiles)
+        emit scriptChanged(file);
+    
+    changedFiles.clear();
+}
 
+
+void ScriptEngine::prepareThis(QScriptEngine &engine){
+    DEBUG_BLOCK
+    
     QScriptValue me = engine.newQObject(&engine);
     engine.globalObject().setProperty(objectName(), me);
 
@@ -168,6 +209,9 @@ void ScriptEngine::prepareThis(QScriptEngine &engine){
 
     QScriptValue getMagnet = engine.newFunction(getMagnets);
     engine.globalObject().setProperty("getMagnets", getMagnet, QScriptValue::ReadOnly);
+	
+    QScriptValue printE = engine.newFunction(printErr);
+    engine.globalObject().setProperty("printErr", printE, QScriptValue::ReadOnly);
 
     QScriptValue import = engine.newFunction(importExtension);
     engine.globalObject().setProperty("Import", import, QScriptValue::ReadOnly);
@@ -193,6 +237,13 @@ void ScriptEngine::prepareThis(QScriptEngine &engine){
     QScriptValue linkParser_parseMagnet = engine.newFunction(parseMagnetAlias);
     linkParser.setProperty("parse", linkParser_parse, QScriptValue::ReadOnly);
     linkParser.setProperty("parseMagnetAlias", linkParser_parseMagnet, QScriptValue::ReadOnly);
+    
+    QScriptValue widgetManager = engine.newQObject(ArenaWidgetManager::getInstance());
+    engine.globalObject().setProperty("WidgetManager", widgetManager, QScriptValue::ReadOnly);
+    
+    qScriptRegisterSequenceMetaType< QList<QObject*> >(&engine);
+    qScriptRegisterMetaType<VarMap>(&engine, ScriptVarMapToScriptValue, ScriptVarMapFromScriptValue);
+    qScriptRegisterMetaType<VarMap>(&engine, ScriptVarMapToScriptValue, ScriptVarMapFromScriptValue);
 
     engine.globalObject().setProperty("LinkParser", linkParser, QScriptValue::ReadOnly);
 
@@ -203,6 +254,8 @@ void ScriptEngine::prepareThis(QScriptEngine &engine){
 }
 
 void ScriptEngine::registerStaticMembers(QScriptEngine &engine){
+    DEBUG_BLOCK
+    
     static QStringList staticMembers = QStringList() << "AntiSpam"          << "DownloadQueue"  << "FavoriteHubs"
                                                      << "Notification"      << "HubManager"     << "ClientManagerScript"
                                                      << "LogManagerScript"  << "FavoriteUsers"  << "HashManagerScript"
@@ -216,6 +269,8 @@ void ScriptEngine::registerStaticMembers(QScriptEngine &engine){
 }
 
 void ScriptEngine::registerDynamicMembers(QScriptEngine &engine){
+    DEBUG_BLOCK
+    
     static QStringList dynamicMembers = QStringList() << "HubFrame" << "SearchFrame" << "ShellCommandRunner" << "MainWindowScript"
                                                       << "ScriptWidget";
 
@@ -227,6 +282,8 @@ void ScriptEngine::registerDynamicMembers(QScriptEngine &engine){
 }
 
 void ScriptEngine::slotWSKeyChanged(const QString &key, const QString &value){
+    DEBUG_BLOCK
+    
     if (key == WS_APP_ENABLED_SCRIPTS){
         QStringList enabled = QString(QByteArray::fromBase64(value.toAscii())).split("\n", QString::SkipEmptyParts);
         QMap<QString, ScriptObject*>::iterator it;
@@ -246,6 +303,16 @@ void ScriptEngine::slotWSKeyChanged(const QString &key, const QString &value){
     }
 }
 
+void ScriptEngine::slotScriptChanged(const QString &script){
+    DEBUG_BLOCK
+    
+    if (!QFile::exists(script))
+        stopScript(script);
+    else if (!changedFiles.contains(script)){
+        changedFiles.push_back(script);
+    }
+}
+
 static QScriptValue shellExec(QScriptContext *ctx, QScriptEngine *engine){
     Q_UNUSED(engine);
 
@@ -322,22 +389,13 @@ static QScriptValue staticMemberConstructor(QScriptContext *context, QScriptEngi
         obj = qobject_cast<QObject*>(AntiSpam::getInstance());
     }
     else if (className == "DownloadQueue"){
-        if (!DownloadQueue::getInstance())
-            DownloadQueue::newInstance();
-
-        obj = qobject_cast<QObject*>(DownloadQueue::getInstance());
+        obj = qobject_cast<QObject*>(ArenaWidgetFactory().create<dcpp::Singleton, DownloadQueue>());
     }
     else if (className == "FavoriteHubs"){
-        if (!FavoriteHubs::getInstance())
-            FavoriteHubs::newInstance();
-
-        obj = qobject_cast<QObject*>(FavoriteHubs::getInstance());
+        obj = qobject_cast<QObject*>(ArenaWidgetFactory().create<dcpp::Singleton, FavoriteHubs>());
     }
     else if (className == "FavoriteUsers"){
-        if (!FavoriteUsers::getInstance())
-            FavoriteUsers::newInstance();
-
-        obj = qobject_cast<QObject*>(FavoriteUsers::getInstance());
+        obj = qobject_cast<QObject*>(ArenaWidgetFactory().create<dcpp::Singleton, FavoriteUsers>());
     }
     else if (className == "Notification"){
         if (Notification::getInstance()){
@@ -347,9 +405,6 @@ static QScriptValue staticMemberConstructor(QScriptContext *context, QScriptEngi
         }
     }
     else if (className == "HubManager"){
-        if (!HubManager::getInstance())
-            HubManager::newInstance();
-
         obj = qobject_cast<QObject*>(HubManager::getInstance());
     }
     else if (className == "ClientManagerScript"){
@@ -402,20 +457,13 @@ static QScriptValue dynamicMemberConstructor(QScriptContext *context, QScriptEng
             QString hub = context->argument(0).toString();
             QString enc = context->argument(1).toString();
 
-            HubFrame *fr = new HubFrame(MainWindow::getInstance(), hub, enc);
-            fr->setAttribute(Qt::WA_DeleteOnClose);
-
-            MainWindow::getInstance()->addArenaWidget(fr);
-            MainWindow::getInstance()->mapWidgetOnArena(fr);
-
-            MainWindow::getInstance()->addArenaWidgetOnToolbar(fr);
+            HubFrame *fr = ArenaWidgetFactory().create<HubFrame, MainWindow*, QString, QString>(MainWindow::getInstance(), hub, enc);
 
             obj = qobject_cast<QObject*>(fr);
         }
     }
     else if (className == "SearchFrame"){
-        SearchFrame *fr = new SearchFrame();
-        fr->setAttribute(Qt::WA_DeleteOnClose);
+        SearchFrame *fr = ArenaWidgetFactory().create<SearchFrame>();
 
         obj = qobject_cast<QObject*>(fr);
     }
@@ -437,9 +485,7 @@ static QScriptValue dynamicMemberConstructor(QScriptContext *context, QScriptEng
         obj = qobject_cast<QObject*>(new MainWindowScript(engine, MainWindow::getInstance()));
     }
     else if (className == "ScriptWidget"){
-        ScriptWidget *wgt = new ScriptWidget();
-
-        obj = qobject_cast<QObject*>(wgt);
+        obj = qobject_cast<QObject*>(ArenaWidgetFactory().create<ScriptWidget>());
     }
 
     return engine->newQObject(obj, QScriptEngine::AutoOwnership);
@@ -509,3 +555,40 @@ static QScriptValue includeFile(QScriptContext *ctx, QScriptEngine *engine){
 
     return ret;
 }
+
+QScriptValue printErr(QScriptContext *ctx, QScriptEngine *engine){
+	if (ctx->argumentCount() < 1)
+        return engine->undefinedValue();
+    
+    QString out = ctx->argument(0).toString();
+    
+    for (int i = 1; i < ctx->argumentCount(); i++)
+        out = out.arg(ctx->argument(i).toString());
+   
+    qWarning() << qPrintable(out);
+    
+    return engine->undefinedValue();
+}
+
+QScriptValue ScriptVarMapToScriptValue(QScriptEngine* eng, const VarMap& map)
+{
+    QScriptValue a = eng->newObject();
+    VarMap::const_iterator it(map.begin());
+    
+    for(; it != map.end(); ++it) {
+        QString prop = it.key();
+        
+        a.setProperty(prop, qScriptValueFromValue(eng, it.value()));
+    }
+
+    return a;
+}
+ 
+void ScriptVarMapFromScriptValue( const QScriptValue& value, VarMap& map){
+    QScriptValueIterator itr(value);
+    
+    while(itr.hasNext()){
+       itr.next();
+       map[itr.name()] = qscriptvalue_cast<VarMap::mapped_type>(itr.value());
+    }
+}
