@@ -9,7 +9,6 @@
 
 #include "ADLS.h"
 #include "ADLSModel.h"
-#include "MainWindow.h"
 #include "WulforUtil.h"
 #include "WulforSettings.h"
 
@@ -31,6 +30,8 @@ ADLS::ADLS(QWidget *parent):
     setupUi(this);
 
     init();
+    
+    ArenaWidget::setState( ArenaWidget::Flags(ArenaWidget::state() | ArenaWidget::Singleton | ArenaWidget::Hidden) );
 }
 
 ADLS::~ADLS(){
@@ -42,20 +43,11 @@ ADLS::~ADLS(){
 
 void ADLS::closeEvent(QCloseEvent *e){
     if (isUnload()){
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-        MainWindow::getInstance()->remArenaWidget(this);
-
         save();
 
-        //setAttribute(Qt::WA_DeleteOnClose);
-
         e->accept();
     }
     else {
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-
         e->ignore();
     }
 }
@@ -105,8 +97,6 @@ void ADLS::init(){
     treeView->setAcceptDrops(false); // temporary
     //treeView->setDragDropMode(QAbstractItemView::InternalMove);
 
-    MainWindow::getInstance()->addArenaWidget(this);
-
     WulforUtil *WU = WulforUtil::getInstance();
 
     add_newButton->setIcon(WU->getPixmap(WulforUtil::eiBOOKMARK_ADD));
@@ -296,7 +286,7 @@ void ADLS::slotUpButtonClicked(){
     QItemSelectionModel *s_model = treeView->selectionModel();
     QModelIndexList list = s_model->selectedRows(0);
 
-    foreach (QModelIndex i, list)
+    foreach (const QModelIndex &i, list)
         s_model->select(model->moveUp(i), QItemSelectionModel::ClearAndSelect|QItemSelectionModel::Rows);
 }
 
@@ -304,7 +294,7 @@ void ADLS::slotDownButtonClicked(){
     QItemSelectionModel *s_model = treeView->selectionModel();
     QModelIndexList list = s_model->selectedRows(0);
 
-    foreach (QModelIndex i, list)
+    foreach (const QModelIndex &i, list)
          s_model->select(model->moveDown(i), QItemSelectionModel::ClearAndSelect|QItemSelectionModel::Rows);
 }
 
@@ -344,8 +334,6 @@ void ADLS::updateEntry(ADLSearch &entry, StrMap &map){
 
 }
 void ADLS::getParams(const ADLSEditor &editor, StrMap &map){
-    WulforUtil *WU = WulforUtil::getInstance();
-
     map["SSTRING"]      = editor.lineEdit_SSTRING->text();
     map["DIRECTORY"]    = editor.lineEdit_DIRECTORY->text();
     map["AUTOQUEUE"]    = editor.checkBox_DOWNLOAD->isChecked();
