@@ -20,17 +20,17 @@
 #include "dcpp/User.h"
 #include "dcpp/DirectoryListing.h"
 
-#define COLUMN_DOWNLOADQUEUE_NAME       0
-#define COLUMN_DOWNLOADQUEUE_STATUS     1
-#define COLUMN_DOWNLOADQUEUE_SIZE       2
-#define COLUMN_DOWNLOADQUEUE_DOWN       3
-#define COLUMN_DOWNLOADQUEUE_PRIO       4
-#define COLUMN_DOWNLOADQUEUE_USER       5
-#define COLUMN_DOWNLOADQUEUE_PATH       6
-#define COLUMN_DOWNLOADQUEUE_ESIZE      7
-#define COLUMN_DOWNLOADQUEUE_ERR        8
-#define COLUMN_DOWNLOADQUEUE_ADDED      9
-#define COLUMN_DOWNLOADQUEUE_TTH        10
+static const unsigned COLUMN_DOWNLOADQUEUE_NAME     = 0;
+static const unsigned COLUMN_DOWNLOADQUEUE_STATUS   = 1;
+static const unsigned COLUMN_DOWNLOADQUEUE_SIZE     = 2;
+static const unsigned COLUMN_DOWNLOADQUEUE_DOWN     = 3;
+static const unsigned COLUMN_DOWNLOADQUEUE_PRIO     = 4;
+static const unsigned COLUMN_DOWNLOADQUEUE_USER     = 5;
+static const unsigned COLUMN_DOWNLOADQUEUE_PATH     = 6;
+static const unsigned COLUMN_DOWNLOADQUEUE_ESIZE    = 7;
+static const unsigned COLUMN_DOWNLOADQUEUE_ERR      = 8;
+static const unsigned COLUMN_DOWNLOADQUEUE_ADDED    = 9;
+static const unsigned COLUMN_DOWNLOADQUEUE_TTH      = 10;
 
 class DownloadQueueDelegate:
         public QStyledItemDelegate
@@ -58,7 +58,7 @@ public:
     DownloadQueueItem *child(int row);
     int childCount() const;
     int columnCount() const;
-    QVariant data(int column) const;
+    const QVariant &data(int column) const;
     int row() const;
     DownloadQueueItem *parent();
     void updateColumn(int, QVariant);
@@ -74,6 +74,8 @@ private:
     DownloadQueueItem *parentItem;
 };
 
+class DownloadQueueModelPrivate;
+
 class DownloadQueueModel: public QAbstractItemModel
 {
     Q_OBJECT
@@ -95,6 +97,7 @@ public:
     int columnCount(const QModelIndex &parent = QModelIndex()) const;
     /** sort list */
     virtual void sort(int column, Qt::SortOrder order = Qt::AscendingOrder);
+    virtual void sort() { sort(getSortColumn(), getSortOrder()); }
 
     /** */
     DownloadQueueItem *addItem(const QMap<QString, QVariant> &);
@@ -135,23 +138,13 @@ Q_SIGNALS:
     void needExpand(const QModelIndex &item);
     void updateStats(quint64 files, quint64 size);
 
-private:
-    /** */
-    quint64 total_files;
-    /** */
-    quint64 total_size;
+private:   
     /** */
     DownloadQueueItem *findTarget(const DownloadQueueItem*, const QString&);
-    /** */
-    int sortColumn;
-    /** */
-    Qt::SortOrder sortOrder;
-    /** */
-    DownloadQueueItem *rootItem;
-    /** */
-    bool iconsScaled;
-    /** */
-    QSize iconsSize;
+    
+    Q_DECLARE_PRIVATE(DownloadQueueModel);
+    
+    DownloadQueueModelPrivate *d_ptr;
 };
 
 #endif //DOWNLOADQUEUEMODEL_H
