@@ -8,7 +8,6 @@
 ***************************************************************************/
 
 #include "FavoriteUsers.h"
-#include "MainWindow.h"
 #include "WulforUtil.h"
 #include "FavoriteUsersModel.h"
 
@@ -71,7 +70,7 @@ FavoriteUsers::FavoriteUsers(QWidget *parent) :
 
     FavoriteManager::getInstance()->addListener(this);
 
-    MainWindow::getInstance()->addArenaWidget(this);
+    ArenaWidget::setState( ArenaWidget::Flags(ArenaWidget::state() | ArenaWidget::Singleton | ArenaWidget::Hidden) );
 }
 
 FavoriteUsers::~FavoriteUsers(){
@@ -81,20 +80,11 @@ FavoriteUsers::~FavoriteUsers(){
 
 void FavoriteUsers::closeEvent(QCloseEvent *e){
     if (isUnload()){
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-        MainWindow::getInstance()->remArenaWidget(this);
-
         WSSET(WS_FAVUSERS_STATE, treeView->header()->saveState().toBase64());
 
-        //setAttribute(Qt::WA_DeleteOnClose);
-
         e->accept();
     }
     else {
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-
         e->ignore();
     }
 }
@@ -108,7 +98,7 @@ bool FavoriteUsers::eventFilter(QObject *obj, QEvent *e){
                 QModelIndexList indexes = treeView->selectionModel()->selectedRows(0);
                 QList<FavoriteUserItem*> items;
 
-                foreach(QModelIndex i, indexes)
+                foreach(const QModelIndex &i, indexes)
                     items.push_back(reinterpret_cast<FavoriteUserItem*>(i.internalPointer()));
 
                 foreach (FavoriteUserItem *i, items)
@@ -240,7 +230,7 @@ void FavoriteUsers::slotContextMenu(){
     QModelIndexList indexes = treeView->selectionModel()->selectedRows(0);
     QList<FavoriteUserItem*> items;
 
-    foreach(QModelIndex i, indexes)
+    foreach(const QModelIndex &i, indexes)
         items.push_back(reinterpret_cast<FavoriteUserItem*>(i.internalPointer()));
 
     if (items.size() < 1)
