@@ -32,7 +32,7 @@ using namespace dcpp;
 static void sortRecursive(int column, Qt::SortOrder order, FileBrowserItem *i);
 
 FileBrowserModel::FileBrowserModel(QObject *parent)
-    : QAbstractItemModel(parent), iconsScaled(false), restrictionsLoaded(false), listing(NULL)
+    : QAbstractItemModel(parent), iconsScaled(false), restrictionsLoaded(false), listing(NULL), ownList(false)
 {
     rootItem = new FileBrowserItem(QList<QVariant>() << tr("") << tr("") << tr("") << tr(""), NULL);
 
@@ -118,7 +118,7 @@ QVariant FileBrowserModel::data(const QModelIndex &index, int role) const
         }
         case Qt::ForegroundRole:
         {
-            if (item->dir)
+            if (item->dir || ownList)
                 break;
 
             TTHValue t(_tq(item->data(COLUMN_FILEBROWSER_TTH).toString()));
@@ -166,16 +166,43 @@ QVariant FileBrowserModel::data(const QModelIndex &index, int role) const
 
                 return tr("File marked as a duplicate of another file: %1").arg(path+_q(file->getName()));
             }
+            
+            QString tooltip = "";
+            
+            if (item->dir){
+                tooltip = item->data(COLUMN_FILEBROWSER_NAME).toString();
+            }
+            
+            if (item->file){
+                DirectoryListing::File *f = item->file;
+                
+                if (!f->mediaInfo.video_info.empty() || !f->mediaInfo.audio_info.empty()){
+                    MediaInfo &mi = f->mediaInfo;
+                    
+                    tooltip = QString("<b>Media Info:</b><br/>"
+                                      "&nbsp;&nbsp;<b>Video:</b> %1<br/>"
+                                      "&nbsp;&nbsp;<b>Audio:</b> %2<br/>"
+                                      "&nbsp;&nbsp;<b>Bitrate:</b> %3<br/>"
+                                      "&nbsp;&nbsp;<b>Resolution:</b> %4<br/><br/>")
+                                      .arg(_q(mi.video_info)).arg(_q(mi.audio_info))
+                                      .arg(mi.bitrate).arg(_q(mi.resolution));
+                }
+            }
 
             TTHValue t(_tq(item->data(COLUMN_FILEBROWSER_TTH).toString()));
             ShareManager *SM = ShareManager::getInstance();
 
-            try{
-                QString toolTip = _q(SM->toReal(SM->toVirtual(t)));
+            if (!ownList){
+                try{
+                    QString toolTip = _q(SM->toReal(SM->toVirtual(t)));
 
-                return tr("File already exists: %1").arg(toolTip);
-            }catch( ... ){};
+                    return tooltip + tr("File already exists: %1").arg(toolTip);
+                }catch( ... ){};
+            }
 
+            if (!tooltip.isEmpty())
+                return tooltip;
+            
             break;
         }
         case Qt::FontRole:
@@ -200,26 +227,29 @@ namespace {
 
 template <Qt::SortOrder order>
 struct Compare {
-    void static sort(int col, QList<FileBrowserItem*>& items) {
-        qStableSort(items.begin(), items.end(), getAttrComp(col));
+    typedef bool (*AttrComp)(const FileBrowserItem * l, const FileBrowserItem * r);
+    
+    void static sort(unsigned  column, QList<FileBrowserItem*>& items) {
+        if (column > COLUMN_FILEBROWSER_TTH)
+            return;
+        
+        qStableSort(items.begin(), items.end(), attrs[column] );
     }
 
-    void static insertSorted(int col, QList<FileBrowserItem*>& items, FileBrowserItem* item) {
-        QList<FileBrowserItem*>::iterator it = qLowerBound(items.begin(), items.end(), item, getAttrComp(col));
+    void static insertSorted(unsigned column, QList<FileBrowserItem*>& items, FileBrowserItem* item) {
+        if (column > COLUMN_FILEBROWSER_TTH)
+            return;
+        
+        QList<FileBrowserItem*>::iterator it = qLowerBound(items.begin(), 
+                                                           items.end(), 
+                                                           item, 
+                                                           attrs[column]
+                                                          );
         items.insert(it, item);
     }
 
     private:
-        typedef bool (*AttrComp)(const FileBrowserItem * l, const FileBrowserItem * r);
-        AttrComp static getAttrComp(const int column) {
-            static AttrComp attrs[4] = {    AttrCmp<COLUMN_FILEBROWSER_NAME>,
-                                            NumCmp<COLUMN_FILEBROWSER_ESIZE>,
-                                            NumCmp<COLUMN_FILEBROWSER_ESIZE>,
-                                            AttrCmp<COLUMN_FILEBROWSER_TTH>
-                                       };
-
-            return attrs[column];
-        }
+        
         template <int i>
         bool static AttrCmp(const FileBrowserItem * l, const FileBrowserItem * r) {
             if ((l->dir && !r->dir) || (!l->dir && r->dir)){
@@ -236,8 +266,17 @@ struct Compare {
        }
         template <typename T>
         bool static Cmp(const T& l, const T& r);
+        
+        static AttrComp attrs[4];
 };
 
+template <Qt::SortOrder order>
+typename Compare<order>::AttrComp Compare<order>::attrs[4] = {  AttrCmp<COLUMN_FILEBROWSER_NAME>,
+                                                                NumCmp<COLUMN_FILEBROWSER_ESIZE>,
+                                                                NumCmp<COLUMN_FILEBROWSER_ESIZE>,
+                                                                AttrCmp<COLUMN_FILEBROWSER_TTH>
+                                                             };
+
 template <> template <typename T>
 bool inline Compare<Qt::AscendingOrder>::Cmp(const T& l, const T& r) {
     return l < r;
@@ -630,12 +669,16 @@ FileBrowserItem::FileBrowserItem(const FileBrowserItem &item){
     dir = item.dir;
     file = item.file;
     isDuplicate = item.isDuplicate;
+    childItems = item.childItems;
+    parentItem = item.parentItem;
 }
 void FileBrowserItem::operator=(const FileBrowserItem &item){
     itemData = item.itemData;
     dir = item.dir;
     file = item.file;
     isDuplicate = item.isDuplicate;
+    childItems = item.childItems;
+    parentItem = item.parentItem;
 }
 
 FileBrowserItem::~FileBrowserItem()
