@@ -21,10 +21,10 @@
 #include "dcpp/User.h"
 #include "dcpp/DirectoryListing.h"
 
-#define COLUMN_FILEBROWSER_NAME     0
-#define COLUMN_FILEBROWSER_SIZE     1
-#define COLUMN_FILEBROWSER_ESIZE    2
-#define COLUMN_FILEBROWSER_TTH      3
+static const unsigned COLUMN_FILEBROWSER_NAME   = 0;
+static const unsigned COLUMN_FILEBROWSER_SIZE   = 1;
+static const unsigned COLUMN_FILEBROWSER_ESIZE  = 2;
+static const unsigned COLUMN_FILEBROWSER_TTH    = 3;
 
 
 class FileBrowserItem
@@ -125,6 +125,8 @@ public:
     void clear();
     /** */
     void repaint();
+    /** */
+    void setOwnList(bool _own){ ownList = _own; }
 
 signals:
     void rootChanged(FileBrowserItem*,FileBrowserItem*);
@@ -150,6 +152,8 @@ private:
     QMap<QString, unsigned> restrict_map;
     /** */
     bool restrictionsLoaded;
+    /** */
+    bool ownList;
 };
 
 #endif // FBMODEL_H
