@@ -384,6 +384,9 @@ void MainWindow::closeEvent(QCloseEvent *c_e){
     if (ConnectionManager::getInstance())
         ConnectionManager::getInstance()->disconnect();
 
+    d->arena->hide();
+    d->arena->setWidget(NULL);
+
     c_e->accept();
 }
 
@@ -1966,7 +1969,10 @@ void MainWindow::toggleSingletonWidget(ArenaWidget *a){
         a->setToolButton(act);
     }
    
-    ArenaWidgetManager::getInstance()->toggle(a);
+    if (!a->getWidget()->isVisible())
+        ArenaWidgetManager::getInstance()->activate(a);
+    else
+        ArenaWidgetManager::getInstance()->toggle(a);
 }
 
 void MainWindow::toggleMainMenu(bool showMenu){
@@ -2231,19 +2237,49 @@ void MainWindow::slotToolsJS(){
 #endif
 }
 
+#ifdef USE_JS
+namespace {
+    enum class ScriptChangedAction: int {
+        DoNothing=0,
+        AskUser,
+        ReloadIt
+    };
+}
+#endif
+
 void MainWindow::slotJSFileChanged(const QString &script){
 #ifdef USE_JS
-    if (!isVisible()){
-        show();
-        
-        raise();
-    }
-    
-    if (QMessageBox::warning(this, 
-                             tr("Script Engine"), 
-                             QString("\'%1\' has been changed. Reload it?").arg(script), 
-                             QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes)
+    enum ScriptChangedAction act = (enum ScriptChangedAction)WIGET("scriptmanager/script-changed-action", 0);
+    bool ask = false;
+
+    switch (act){
+    case ScriptChangedAction::DoNothing:
+        break;
+    case ScriptChangedAction::AskUser:
+        ask = true;
+    case ScriptChangedAction::ReloadIt:
+    {
+        auto raiseMe = [this]() -> bool {
+            if (!this->isVisible()){
+                this->show();
+                this->raise();
+            }
+
+            return true;
+        };
+
+        if (ask && raiseMe() && (QMessageBox::warning(this,
+                                                      tr("Script Engine"),
+                                                      QString("\'%1\' has been changed. Reload it?").arg(script),
+                                                      QMessageBox::Yes, QMessageBox::No) != QMessageBox::Yes))
+            break;
+
+
         ScriptEngine::getInstance()->loadScript(script);
+
+        break;
+    }
+    }
 #endif
 }
 
@@ -2595,112 +2631,112 @@ void MainWindow::slotAboutClient(){
     a.label_ABOUT->setText(about_text);
 
     a.textBrowser_AUTHORS->setText(
-            tr("Please use <a href=\"http://code.google.com/p/eiskaltdc/issues/list\">"
-               "http://code.google.com/p/eiskaltdc/issues/list</a> to report bugs.<br/>")+
-            tr("<br/>"
-               "<b>Developers</b><br/>")+
-            tr("<br/>"
-               "&nbsp;Andrey Karlov<br/>"
-               "&nbsp;&lt;dein.negativ@gmail.com&gt;<br/>"
-               "&nbsp;(main developer 0.4.10 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;Boris Pek  aka  Tehnick<br/>"
-               "&nbsp;&lt;tehnick-8@mail.ru&gt;<br/>"
-               "&nbsp;(maintainer and developer 1.89.0 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;Eugene Petrov<br/>"
-               "&nbsp;&lt;dhamp@ya.ru&gt;<br/>"
-               "&nbsp;(maintainer and developer 0.4.10 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;Alexandr Tkachev<br/>"
-               "&nbsp;&lt;tka4ev@gmail.com&gt;<br/>"
-               "&nbsp;(developer 2.0.3 and later)<br/>")+
-            tr("<br/>"
-               "<b>Logo and Splash Screen Logo</b><br/>")+
-            tr("<br/>"
-               "&nbsp;Uladzimir Bely<br/>"
-               "&nbsp;&lt;wiselord1983@gmail.com&gt;<br/>"
-               "&nbsp;(version 0.4.10 and later)<br/>")
-            );
+        tr("Please use <a href=\"http://code.google.com/p/eiskaltdc/issues/list\">"
+        "http://code.google.com/p/eiskaltdc/issues/list</a> to report bugs.<br/>")+
+        QString("<br/>")+
+        tr("<b>Developers</b><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Andrey Karlov &lt;dein.negativ@gmail.com&gt;<br/>")+
+        tr("&nbsp; (main developer 0.4.10 and later)<br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Boris Pek aka Tehnick &lt;tehnick-8@mail.ru&gt;<br/>")+
+        tr("&nbsp; (maintainer and developer 1.89.0 and later)<br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Eugene Petrov &lt;dhamp@ya.ru&gt;<br/>")+
+        tr("&nbsp; (maintainer and developer 0.4.10 and later)<br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Alexandr Tkachev &lt;tka4ev@gmail.com&gt;<br/>")+
+        tr("&nbsp; (developer 2.0.3 and later)<br/>")+
+        QString("<br/>")+
+        tr("<b>Logo</b><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Uladzimir Bely &lt;wiselord1983@gmail.com&gt;<br/>")+
+        tr("&nbsp; (version 0.4.10 and later)<br/>")
+        );
 
     a.textBrowser_TRANSLATION->setText(
-            tr("<b>Translators</b><br/>")+
-            tr("<br/>"
-               "&nbsp;<u>Russian translation</u><br/>")+
-            tr("<br/>"
-               "&nbsp;Uladzimir Bely<br/>"
-               "&nbsp;&lt;wiselord1983@gmail.com&gt;<br/>"
-               "&nbsp;(for 0.4.10 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;Boris Pek  aka  Tehnick<br/>"
-               "&nbsp;&lt;tehnick-8@mail.ru&gt;<br/>"
-               "&nbsp;(for 2.1.0 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;<u>Belarusian translation</u><br/>")+
-            tr("<br/>"
-               "&nbsp;Paval Shalamitski  aka  Klyok<br/>"
-               "&nbsp;&lt;i.kliok@gmail.com&gt;<br/>"
-               "&nbsp;(for 1.0.40 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;<u>Hungarian translation</u><br/>")+
-            tr("<br/>"
-               "&nbsp;Akos Berki  aka  sumo<br/>"
-               "&nbsp;&lt;husumo@gmail.com&gt;<br/>"
-               "&nbsp;(for 2.0.1 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;<u>French translation</u><br/>")+
-            tr("<br/>"
-               "&nbsp;Alexandre Wallimann  aka  Ale<br/>"
-               "&nbsp;&lt;alexandre.wallimann@gmail.com&gt;<br/>"
-               "&nbsp;(for 2.0.2 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;<u>Polish translation</u><br/>")+
-            tr("<br/>"
-               "&nbsp;Arahael<br/>"
-               "&nbsp;(for 2.0.2 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;<u>Ukrainian translation</u><br/>")+
-            tr("<br/>"
-               "&nbsp;Dmytro Demenko<br/>"
-               "&nbsp;&lt;dmytro.demenko@gmail.com&gt;<br/>"
-               "&nbsp;(for 2.0.3 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;<u>Serbian translation</u><br/>")+
-            tr("<br/>"
-               "&nbsp;Miroslav Petrovic<br/>"
-               "&nbsp;&lt;miroslav031@gmail.com&gt;<br/>"
-               "&nbsp;(for 2.0.3 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;<u>Spanish translation</u><br/>")+
-            tr("<br/>"
-               "&nbsp;Gustavo Alvarez aka sL1pKn07<br/>"
-               "&nbsp;&lt;sl1pkn07@gmail.com&gt;<br/>"
-               "&nbsp;(for 2.1.0 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;<u>Bulgarian translation</u><br/>")+
-            tr("<br/>"
-               "&nbsp;Rusi Dimitrov aka PsyTrip<br/>"
-               "&nbsp;&lt;dimitrov.rusi@gmail.com&gt;<br/>"
-               "&nbsp;(for 2.1.0 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;<u>Slovak translation</u><br/>")+
-            tr("<br/>"
-               "&nbsp;Martin Durisin<br/>"
-               "&nbsp;&lt;martin.durisin@gmail.com&gt;<br/>"
-               "&nbsp;(for 2.1.0 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;<u>Czech translation</u><br/>")+
-            tr("<br/>"
-               "&nbsp;Uhlik<br/>"
-               "&nbsp;&lt;uhlikx@seznam.cz&gt;<br/>"
-               "&nbsp;(for 2.2.0 and later)<br/>")+
-            tr("<br/>"
-               "&nbsp;<u>German translation</u><br/>")+
-            tr("<br/>"
-               "&nbsp;Chris Leick<br/>"
-               "&nbsp;&lt;c.leick@vollbio.de&gt;<br/>"
-               "&nbsp;(for 2.2.3 and later)<br/>")
-            );
+        tr("&nbsp;<u>Russian translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Uladzimir Bely &lt;wiselord1983@gmail.com&gt;<br/>")+
+        tr("&nbsp; (for 0.4.10 and later)<br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Boris Pek aka Tehnick &lt;tehnick-8@mail.ru&gt;<br/>")+
+        tr("&nbsp; (for 2.1.0 and later)<br/>")+
+        QString("<br/>")+
+        tr("&nbsp;<u>Belarusian translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Paval Shalamitski aka Klyok &lt;i.kliok@gmail.com&gt;<br/>")+
+        tr("&nbsp; (for 1.0.40 and later)<br/>")+
+        QString("<br/>")+
+        tr("&nbsp;<u>Hungarian translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Akos Berki aka sumo &lt;husumo@gmail.com&gt;<br/>")+
+        tr("&nbsp; (for 2.0.1 and later)<br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Márk Lutring &lt;marcus@elitemail.hu&gt;<br/>")+
+        tr("&nbsp; (for 2.2.5 and later)<br/>")+
+        QString("<br/>")+
+        tr("&nbsp;<u>French translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Alexandre Wallimann aka Ale &lt;alexandre.wallimann@gmail.com&gt;<br/>")+
+        tr("&nbsp; (for 2.0.2 and later)<br/>")+
+        QString("<br/>")+
+        tr("&nbsp;<u>Polish translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Arahael &lt;arahael@gmail.com&gt;<br/>")+
+        tr("&nbsp; (for 2.0.2 and later)<br/>")+
+        QString("<br/>")+
+        tr("&nbsp;<u>Ukrainian translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Dmytro Demenko &lt;dmytro.demenko@gmail.com&gt;<br/>")+
+        tr("&nbsp; (for 2.0.3 and later)<br/>")+
+        QString("<br/>")+
+        tr("&nbsp;<u>Serbian (Latin) translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Miroslav Petrovic &lt;miroslav031@gmail.com&gt;<br/>")+
+        tr("&nbsp; (for 2.0.3 and later)<br/>")+
+        QString("<br/>")+
+        tr("&nbsp;<u>Spanish translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Gustavo Alvarez aka sL1pKn07 &lt;sl1pkn07@gmail.com&gt;<br/>")+
+        tr("&nbsp; (for 2.1.0 and later)<br/>")+
+        QString("<br/>")+
+        tr("&nbsp;<u>Bulgarian translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Rusi Dimitrov aka PsyTrip &lt;dimitrov.rusi@gmail.com&gt;<br/>")+
+        tr("&nbsp; (for 2.1.0 and later)<br/>")+
+        QString("<br/>")+
+        tr("&nbsp;<u>Slovak translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Martin Durisin &lt;martin.durisin@gmail.com&gt;<br/>")+
+        tr("&nbsp; (for 2.1.0 and later)<br/>")+
+        QString("<br/>")+
+        tr("&nbsp;<u>Czech translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Uhlik &lt;uhlikx@seznam.cz&gt;<br/>")+
+        tr("&nbsp; (for 2.2.0 and later)<br/>")+
+        QString("<br/>")+
+        tr("&nbsp;<u>German translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Konstantinos Georgokitsos &lt;kgeorgokitsos@yahoo.de&gt;<br/>")+
+        tr("&nbsp; (for 2.2.5 and later)<br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Tillmann Karras &lt;tilkax@gmail.com&gt;<br/>")+
+        tr("&nbsp; (for 2.2.5 and later)<br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Benjamin Weber &lt;be.w@mail.ru&gt;<br/>")+
+        tr("&nbsp; (for 2.2.6 and later)<br/>")+
+        QString("<br/>")+
+        tr("&nbsp;<u>Greek translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Konstantinos Georgokitsos &lt;kgeorgokitsos@yahoo.de&gt;<br/>")+
+        tr("&nbsp; (for 2.2.5 and later)<br/>")+
+        QString("<br/>")+
+        tr("&nbsp;<u>Italian translation</u><br/>")+
+        QString("<br/>")+
+        QString("&nbsp; Stefano Simoncelli &lt;netcelli@gmail.com&gt;<br/>")+
+        tr("&nbsp; (for 2.2.6 and later)<br/>")
+        );
 
     a.exec();
 }
