@@ -16,6 +16,7 @@
 #include "EmoticonFactory.h"
 #include "EmoticonDialog.h"
 #include "FlowLayout.h"
+#include "ArenaWidgetManager.h"
 
 #include "dcpp/stdinc.h"
 #include "dcpp/ClientManager.h"
@@ -118,7 +119,7 @@ PMWindow::PMWindow(QString cid, QString hubUrl):
         }
     }
 
-    connect(close_wnd, SIGNAL(triggered()), this, SLOT(close()));
+    connect(close_wnd, SIGNAL(triggered()), this, SLOT(slotClose()));
     connect(pushButton_HUB, SIGNAL(clicked()), this, SLOT(slotHub()));
     connect(pushButton_SHARE, SIGNAL(clicked()), this, SLOT(slotShare()));
     connect(toolButton_SMILE, SIGNAL(clicked()), this, SLOT(slotSmile()));
@@ -133,6 +134,8 @@ PMWindow::PMWindow(QString cid, QString hubUrl):
 
     out_messages_index = 0;
     out_messages_unsent = false;
+    
+    setState(state() & ~ArenaWidget::RaiseOnStart);// Do not allow PMWindow to be automatically showed by default
 }
 
 void PMWindow::setCompleter(QCompleter *completer, UserListModel *model) {
@@ -140,7 +143,11 @@ void PMWindow::setCompleter(QCompleter *completer, UserListModel *model) {
 }
 
 PMWindow::~PMWindow(){
-    delete arena_menu;
+    arena_menu->deleteLater();
+}
+
+void PMWindow::slotClose() {
+    ArenaWidgetManager::getInstance()->rem(this);
 }
 
 bool PMWindow::eventFilter(QObject *obj, QEvent *e){
@@ -171,7 +178,7 @@ bool PMWindow::eventFilter(QObject *obj, QEvent *e){
         {
             QString msg = plainTextEdit_INPUT->toPlainText();
 
-            HubFrame *fr = HubManager::getInstance()->getHub(hubUrl);
+            HubFrame *fr = qobject_cast<HubFrame*>(HubManager::getInstance()->getHub(hubUrl));
 
             if (fr){
                 if (!fr->parseForCmd(msg, this))
@@ -216,7 +223,7 @@ bool PMWindow::eventFilter(QObject *obj, QEvent *e){
             textEdit_CHAT->viewport()->setCursor(Qt::IBeamCursor);
     }
     else if (e->type() == QEvent::MouseButtonDblClick){
-        HubFrame *fr = HubManager::getInstance()->getHub(hubUrl);
+        HubFrame *fr = qobject_cast<HubFrame*>(HubManager::getInstance()->getHub(hubUrl));
         bool cursoratnick = false;
         QString nick = "",nickstatus="",nickmessage="";
         QString cid = "";
@@ -272,12 +279,8 @@ bool PMWindow::eventFilter(QObject *obj, QEvent *e){
 void PMWindow::closeEvent(QCloseEvent *c_e){
     emit privateMessageClosed(cid);
 
-    MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-    MainWindow::getInstance()->remArenaWidget(this);
-
     hasMessages = false;
     hasHighlightMessages = false;
-    MainWindow::getInstance()->redrawToolPanel();
 
     c_e->accept();
 }
@@ -290,8 +293,6 @@ void PMWindow::showEvent(QShowEvent *e){
         hasHighlightMessages = false;
         MainWindow::getInstance()->redrawToolPanel();
     }
-
-    MainWindow::getInstance()->mapWidgetOnArena(this);
 }
 
 void PMWindow::slotActivate(){
@@ -486,10 +487,10 @@ void PMWindow::prevMsg(){
 }
 
 void PMWindow::slotHub(){
-    HubFrame *fr = HubManager::getInstance()->getHub(hubUrl);
+    HubFrame *fr = qobject_cast<HubFrame*>(HubManager::getInstance()->getHub(hubUrl));
 
     if (fr)
-        MainWindow::getInstance()->mapWidgetOnArena(fr);
+        ArenaWidgetManager::getInstance()->activate(fr);
 }
 
 void PMWindow::slotShare(){
@@ -580,7 +581,7 @@ void PMWindow::slotSmileContextMenu(){
     QMenu *m = new QMenu(this);
     QAction * a = NULL;
 
-    foreach (QString f, QDir(emot).entryList(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot)){
+    foreach (const QString &f, QDir(emot).entryList(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot)){
         if (!f.isEmpty()){
             QAction * act = m->addAction(f);
             act->setCheckable(true);
