@@ -8,7 +8,6 @@
 ***************************************************************************/
 
 #include "QueuedUsers.h"
-#include "MainWindow.h"
 #include "WulforSettings.h"
 
 #include "dcpp/UploadManager.h"
@@ -32,7 +31,8 @@ QueuedUsers::QueuedUsers(){
     connect(treeView_USERS, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotContextMenu()));
 
     UploadManager::getInstance()->addListener(this);
-    MainWindow::getInstance()->addArenaWidget(this);
+    
+    ArenaWidget::setState( ArenaWidget::Flags(ArenaWidget::state() | ArenaWidget::Singleton | ArenaWidget::Hidden) );
 }
 
 QueuedUsers::~QueuedUsers(){
@@ -43,16 +43,9 @@ void QueuedUsers::closeEvent(QCloseEvent *e){
     if (isUnload()){
         WVSET("queued-users/headerstate", treeView_USERS->header()->saveState());
 
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-        MainWindow::getInstance()->remArenaWidget(this);
-
         e->accept();
     }
     else {
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-
         e->ignore();
     }
 }
@@ -75,7 +68,7 @@ void QueuedUsers::slotContextMenu(){
     m->addAction(tr("Grant slot"));
 
     if (m->exec(QCursor::pos())){
-        foreach (QModelIndex i, indexes){
+        foreach (const QModelIndex &i, indexes){
             QueuedUserItem *item = reinterpret_cast<QueuedUserItem*>(i.internalPointer());
 
             if (!item)
