@@ -43,8 +43,6 @@
 #include <QInputDialog>
 #include <QDesktopServices>
 
-#include <boost/bind.hpp>
-
 using namespace dcpp;
 
 AsyncRunner::AsyncRunner(QObject *parent): QThread(parent){
@@ -59,7 +57,7 @@ void AsyncRunner::run(){
     runFunc();
 }
 
-void AsyncRunner::setRunFunction(const boost::function<void()> &f){
+void AsyncRunner::setRunFunction(const std::function<void()> &f){
     runFunc = f;
 }
 
@@ -218,11 +216,12 @@ ShareBrowser::ShareBrowser(UserPtr user, QString file, QString jump_to):
         else
             title = tr("Listing: ") + nick;
     }
+
+    connect(this, SIGNAL(die(QString)), this, SLOT(slotDie(QString)), Qt::QueuedConnection);
     
     AsyncRunner *runner = new AsyncRunner(this);
-    boost::function<void()> f = boost::bind(&ShareBrowser::buildList, this);
 
-    runner->setRunFunction(f);
+    runner->setRunFunction([this]() { this->buildList(); });
     connect(runner, SIGNAL(finished()), this, SLOT(init()), Qt::QueuedConnection);
     connect(runner, SIGNAL(finished()), runner, SLOT(deleteLater()), Qt::QueuedConnection);
 
@@ -312,7 +311,6 @@ void ShareBrowser::init(){
     QAction *close_wnd = new QAction(WICON(WulforUtil::eiFILECLOSE), tr("Close"), arena_menu);
     arena_menu->addAction(close_wnd);
 
-    //connect(treeView_LPANE, SIGNAL(clicked(const QModelIndex&)), this, SLOT(slotLeftPaneClicked(QModelIndex)));
     connect(treeView_LPANE, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotCustomContextMenu(QPoint)));
     connect(treeView_LPANE->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
             this, SLOT(slotLeftPaneSelChanged(QItemSelection,QItemSelection)));
@@ -422,7 +420,7 @@ void ShareBrowser::buildList(){
         ADLSearchManager::getInstance()->matchListing(listing);
     }
     catch (const Exception &e){
-        LogManager::getInstance()->message(e.what());
+        emit die(tr("Share browser error: %1").arg(_q(e.what())));
     }
 }
 
@@ -602,17 +600,26 @@ void ShareBrowser::changeRoot(dcpp::DirectoryListing::Directory *root){
 }
 
 void ShareBrowser::slotRightPaneSelChanged(const QItemSelection &, const QItemSelection &){
-    QItemSelectionModel *selection_model = treeView_RPANE->selectionModel();
-    QModelIndexList list = selection_model->selectedRows(0);
-    quint64 selected_size = 0;
+    QModelIndexList list        = treeView_RPANE->selectionModel()->selectedRows(COLUMN_FILEBROWSER_NAME);
+    qulonglong selected_size    = 0;
+    quint32    total_selected   = 0;
 
-    foreach (const QModelIndex &i, list)
-        selected_size += (reinterpret_cast<FileBrowserItem*>(i.internalPointer()))->data(COLUMN_FILEBROWSER_ESIZE).toULongLong();
+    std::for_each(list.begin(), list.end(),  
+                  [&total_selected, &selected_size](const QModelIndex &i) {
+                      selected_size += reinterpret_cast<FileBrowserItem*>(i.internalPointer())->data(COLUMN_FILEBROWSER_ESIZE).toULongLong();
+                      total_selected++;
+                  } 
+                 );
+   
+    QString status;
+    
+    if (total_selected > 0)
+        status = tr("Selected %1 from %2 items; ").arg(total_selected).arg(list_root->childCount());
+    
+    status += tr("Total size: %1").arg(WulforUtil::formatBytes(current_size));
 
-    QString status = QString(tr("Total size: %1")).arg(WulforUtil::formatBytes(current_size));
-
-    if (selected_size)
-        status += QString(tr("; Selected: %1")).arg(WulforUtil::formatBytes(selected_size));
+    if (selected_size > 0)
+        status += tr("; Selected: %1").arg(WulforUtil::formatBytes(selected_size));
 
     label_RIGHT->setText(status);
 }
@@ -1082,3 +1089,9 @@ void ShareBrowser::slotSettingsChanged(const QString &key, const QString&){
 void ShareBrowser::slotClose() {
     ArenaWidgetManager::getInstance()->rem(this);
 }
+
+void ShareBrowser::slotDie(const QString &msg){
+    QMessageBox::warning(MainWindow::getInstance(), tr("Share browser"), msg, QMessageBox::Ok);
+
+    slotClose();
+}
