@@ -8,10 +8,10 @@
 ***************************************************************************/
 
 #include "SpyFrame.h"
-#include "MainWindow.h"
 #include "SpyModel.h"
 #include "WulforUtil.h"
 #include "SearchFrame.h"
+#include "ArenaWidgetFactory.h"
 
 #include <QMenu>
 #include <QMessageBox>
@@ -31,14 +31,13 @@ SpyFrame::SpyFrame(QWidget *parent) :
     treeView->setModel(model);
     treeView->setContextMenuPolicy(Qt::CustomContextMenu);
 
-    MainWindow::getInstance()->addArenaWidget(this);
-
     connect(this, SIGNAL(coreIncomingSearch(QString,bool)), model, SLOT(addResult(QString,bool)), Qt::QueuedConnection);
-
     connect(pushButton, SIGNAL(clicked()), this, SLOT(slotStartStop()));
     connect(pushButton_CLEAR, SIGNAL(clicked()), this, SLOT(slotClear()));
     connect(treeView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(contextMenu()));
     connect(WulforSettings::getInstance(), SIGNAL(strValueChanged(QString,QString)), this, SLOT(slotSettingsChanged(QString,QString)));
+    
+    ArenaWidget::setState( ArenaWidget::Flags(ArenaWidget::state() | ArenaWidget::Singleton | ArenaWidget::Hidden) );
 }
 
 SpyFrame::~SpyFrame(){
@@ -47,14 +46,6 @@ SpyFrame::~SpyFrame(){
 
 void SpyFrame::closeEvent(QCloseEvent *e){
     if (isUnload()){
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-        MainWindow::getInstance()->remArenaWidget(this);
-
-        //setAttribute(Qt::WA_DeleteOnClose);
-
-        //save();
-
         e->accept();
     }
     else {
@@ -68,9 +59,6 @@ void SpyFrame::closeEvent(QCloseEvent *e){
                 slotStartStop();
         }
 
-        MainWindow::getInstance()->remArenaWidgetFromToolbar(this);
-        MainWindow::getInstance()->remWidgetFromArena(this);
-
         e->ignore();
     }
 }
@@ -112,7 +100,7 @@ void SpyFrame::contextMenu(){
     if (!ret)
         return;
 
-    SearchFrame *fr = new SearchFrame(this);
+    SearchFrame *fr = ArenaWidgetFactory().create<SearchFrame, QWidget*>(this);
     QString src = item->data(COLUMN_SPY_STRING).toString();
 
     if (item->isTTH){
@@ -137,6 +125,11 @@ void SpyFrame::on(dcpp::ClientManagerListener::IncomingSearch, const string &s)
 
     emit coreIncomingSearch(_q(s).replace("$", " "), isTTH);
 
-    if (checkBox_AUTOSCROLLING->isChecked())
-        treeView->scrollToBottom();
+    if (checkBox_AUTOSCROLLING->isChecked()){
+        treeView->scrollToTop();
+        model->setSort(false);
+    }
+    else{
+        model->setSort(true);
+    }
 }
