@@ -584,11 +584,11 @@ QString UserListItem::getTag()  const{
 }
 
 bool UserListItem::isOP()  const{
-    return id.isOp();
+    return _isOp;
 }
 
 bool UserListItem::isFav()  const{
-    return FavoriteManager::getInstance()->isFavoriteUser(ptr);
+    return _isFav;
 }
 
 bool UserListItem::isAway() const {
@@ -596,6 +596,9 @@ bool UserListItem::isAway() const {
 }
 
 void UserListItem::updateIdentity() {
-    if (ptr != NULL)
-        id = dcpp::ClientManager::getInstance()->getOnlineUserIdentity(ptr);
+    if (ptr != NULL){
+        id      = dcpp::ClientManager::getInstance()->getOnlineUserIdentity(ptr);
+        _isOp   = id.isOp();
+        _isFav  = dcpp::FavoriteManager::getInstance()->isFavoriteUser(ptr);
+    }
 }
