@@ -10,6 +10,7 @@
 #include "MainWindow.h"
 #include "Magnet.h"
 #include "WulforUtil.h"
+#include "ArenaWidgetFactory.h"
 #include "icons/gv.xpm"
 
 #ifdef HAVE_IFADDRS_H
@@ -43,6 +44,7 @@
 #include <QPushButton>
 #include <QFrame>
 #include <QHBoxLayout>
+#include <QRegExp>
 
 #include "SearchFrame.h"
 
@@ -332,6 +334,9 @@ bool WulforUtil::loadIcons(){
     m_PixmapMap[eiUPLIST]       = FROMTHEME("go-up-search", resourceFound);
     m_PixmapMap[eiZOOM_IN]      = FROMTHEME("zoom-in", resourceFound);
     m_PixmapMap[eiZOOM_OUT]     = FROMTHEME("zoom-out", resourceFound);
+    m_PixmapMap[eiTOP]          = FROMTHEME("go-top", resourceFound);
+    m_PixmapMap[eiNEXT]         = FROMTHEME("go-next", resourceFound);
+    m_PixmapMap[eiPREVIOUS]     = FROMTHEME("go-previous", resourceFound);
 
     m_PixmapMap[eiFILETYPE_APPLICATION] = FROMTHEME("application-x-executable", resourceFound);
     m_PixmapMap[eiFILETYPE_ARCHIVE]     = FROMTHEME("application-x-archive", resourceFound);
@@ -654,7 +659,7 @@ void WulforUtil::initFileTypes(){
     m_FileTypeMap["TS"]    = eiFILETYPE_VIDEO;
 }
 
-QPixmap WulforUtil::getPixmapForFile(const QString &file){
+const QPixmap &WulforUtil::getPixmapForFile(const QString &file){
     QString ext = QFileInfo(file).suffix().toUpper();
 
     if (m_FileTypeMap.contains(ext))
@@ -750,7 +755,7 @@ bool WulforUtil::openUrl(const QString &url){
             if (!hub.isEmpty())
                 WulforUtil::openUrl(hub);
 
-            SearchFrame *sfr = new SearchFrame();
+            SearchFrame *sfr = ArenaWidgetFactory().create<SearchFrame>();
             sfr->fastSearch(keywords, false);
         }
         else {
@@ -1089,8 +1094,8 @@ QMenu *WulforUtil::buildUserCmdMenu(const QList<QString> &hub_list, int ctx, QWi
     dcpp::StringList hubs;
     QMap<QString, QMenu*> registered_menus;
 
-    foreach (QString s, hub_list)
-        hubs.push_back(s.toStdString());
+    foreach (const QString &s, hub_list)
+        hubs.push_back(_tq(s));
 
     hubs.push_back("");
 
@@ -1165,3 +1170,8 @@ QMenu *WulforUtil::buildUserCmdMenu(const QList<QString> &hub_list, int ctx, QWi
 
     return usr_menu;
 }
+
+bool WulforUtil::isTTH ( const QString& text ) {
+    return ((text.length() == 39) && (QRegExp("[A-Z0-9]+").exactMatch(text))); 
+}
+
